from enum import Enum


class MetadataNetwork(Enum):
    hangzhounet = 'hangzhounet'
    ithacanet = 'ithacanet'
    mainnet = 'mainnet'
